@@ -1,5 +1,4 @@
 package App::GitHub;
-our $VERSION = '0.01';
 
 use strict;
 use warnings;
@@ -11,6 +10,8 @@ use Net::GitHub;
 use Term::ReadLine;
 use JSON::XS;
 
+our $VERSION = '0.02';
+
 has 'term' => (
     is      => 'ro',
     isa     => 'Object',
@@ -42,6 +43,7 @@ has '_data' => ( is => 'rw', isa => 'HashRef', default => sub { {} } );
 my $dispatch = {
     'exit' => sub { exit; },
     'quit' => sub { exit; },
+    'q'    => sub { exit; },
     '?'    => \&help,
     'h'    => \&help,
 
@@ -50,27 +52,46 @@ my $dispatch = {
     login => \&set_login,
 
     # Repo
-    show => sub {
-        my ( $self, $args ) = @_;
-        if ( $args and $args =~ /^([\-\w]+)[\/\\]([\-\w]+)$/ ) {
-            $self->run_github("repos->show('$1', '$2')");
-        }
-        else {
-            $self->run_github('repos->show()');
-        }
+    rshow    => \&repo_show,
+    rlist    => \&repo_list,
+    findrepo => sub {
+        my ( $self, $word ) = @_;
+        $self->run_github("repos->search('$word')");
     },
-    list => sub {
-        my ( $self, $args ) = @_;
-        if ( $args and $args =~ /^[\w\-]+$/ ) {
-            $self->run_github("repos->list('$args')");
-        }
-        else {
-            $self->run_github('repos->list()');
-        }
+    watch       => sub { shift->run_github('repos->watch()'); },
+    unwatch     => sub { shift->run_github('repos->unwatch()'); },
+    fork        => sub { shift->run_github('repos->fork()'); },
+    create      => \&repo_create,
+    delete      => \&repo_delete,
+    set_private => sub { shift->run_github('repos->set_private()'); },
+    set_public  => sub { shift->run_github('repos->set_public()'); },
+
+    # XXX? TODO, deploy_keys collaborators
+    network  => sub { shift->run_github('repos->network()'); },
+    tags     => sub { shift->run_github('repos->tags()'); },
+    branches => sub { shift->run_github('repos->branches()'); },
+
+    # Issues
+    ilist => sub {
+        my ( $self, $type ) = @_;
+        $type ||= 'open';
+        $self->run_github("issue->list('$type')");
+    },
+    iview => sub {
+        my ( $self, $number ) = @_;
+        $self->run_github("issue->view($number)");
+    },
+    iopen  => \&issue_open,
+    iclose => sub {
+        my ( $self, $number ) = @_;
+        $self->run_github("issue->close($number)");
+    },
+    ireopen => sub {
+        my ( $self, $number ) = @_;
+        $self->run_github("issue->reopen($number)");
     },
 
-    watch   => sub { shift->run_github('repos->watch()'); },
-    unwatch => sub { shift->run_github('repos->unwatch()'); },
+    # XXX? TODO, add_label, edit etc
 
     # File/Path
     cd => sub {
@@ -82,9 +103,9 @@ my $dispatch = {
 sub run {
     my $self = shift;
 
-    print <<'START';
+    print <<START;
 
-Welcome to GitHub Command Tools!
+Welcome to GitHub Command Tools! (Ver: $VERSION)
 Type '?' or 'h' for help.
 START
 
@@ -117,22 +138,39 @@ START
 sub help {
     print <<HELP;
  command  argument          description
- repo     :user/:repo       set owner/repo
-                            eg: 'fayland/perl-app-github'
+ repo     :user :repo       set owner/repo, eg: 'fayland perl-app-github'
  login    :login :token     authenticated as :login
  ?,h                        help
+ q,exit,quit                  exit
 
 Repos
- show     ?:user/:repo      more in-depth information for a repository
-                            (default by repo command)
- list     ?:user            list out all the repositories for a user
-                            (default by repo command)
+ rshow                      more in-depth information for the :repo in repo
+ rlist                      list out all the repositories for the :user in repo
+ rsearch  WORD              Search Repositories
  watch                      watch repositories (authentication required)
  unwatch                    unwatch repositories (authentication required)
+ fork                       fork a repository (authentication required)
+ create                     create a new repository (authentication required)
+ delete                     delete a repository (authentication required)
+ set_private                set a public repo private (authentication required)
+ set_public                 set a private repo public (authentication required)
+ network                    see all the forks of the repo
+ tags                       tags on the repo
+ branches                   list of remote branches
+
+Issues
+ ilist    open|closed       see a list of issues for a project
+ iview    :number           get data on an individual issue by number
+ iopen                      open a new issue (authentication required)
+ iclose   :number           close an issue (authentication required)
+ ireopen  :number           reopen an issue (authentication required)
 
 File/Path related
  cd       PATH              chdir to PATH
 
+Others
+ show     :user :repo       more in-depth information for a repository
+ list     :user             list out all the repositories for a user
 HELP
 }
 
@@ -140,11 +178,11 @@ sub set_repo {
     my ( $self, $repo ) = @_;
 
     # validate
-    unless ( $repo =~ /^([\-\w]+)[\/\\]([\-\w]+)$/ ) {
+    unless ( $repo =~ /^([\-\w]+)[\/\\\s]([\-\w]+)$/ ) {
         print "Wrong repo args ($repo), eg fayland/perl-app-github\n";
         return;
     }
-    my ( $owner, $name ) = ( $repo =~ /^([\-\w]+)[\/\\]([\-\w]+)$/ );
+    my ( $owner, $name ) = ( $repo =~ /^([\-\w]+)[\/\\\s]([\-\w]+)$/ );
     $self->{_data}->{owner} = $owner;
     $self->{_data}->{repo}  = $name;
 
@@ -216,6 +254,70 @@ ERR
     }
 }
 
+################## Repos
+sub repo_show {
+    my ( $self, $args ) = @_;
+    if ( $args and $args =~ /^([\-\w]+)[\/\\\s]([\-\w]+)$/ ) {
+        $self->run_github("repos->show('$1', '$2')");
+    }
+    else {
+        $self->run_github('repos->show()');
+    }
+}
+
+sub repo_list {
+    my ( $self, $args ) = @_;
+    if ( $args and $args =~ /^[\w\-]+$/ ) {
+        $self->run_github("repos->list('$args')");
+    }
+    else {
+        $self->run_github('repos->list()');
+    }
+}
+
+sub repo_create {
+    my ($self) = @_;
+
+    my %data;
+    foreach my $col ( 'name', 'desc', 'homepage' ) {
+        my $data = $self->term->readline( ucfirst($col) . ': ' );
+        $data{$col} = $data;
+    }
+    unless ( length( $data{name} ) ) {
+        print <<'ERR';
+create repo failed. name is required
+ERR
+        return;
+    }
+
+    $self->run_github(
+        qq~repos->create( "$data{name}", "$data{desc}", "$data{homepage}", 1 )~
+    );
+}
+
+sub repo_del {
+    my ($self) = @_;
+
+    my $data = $self->term->readline('Are you sure to delete the repo? [YN]? ');
+    if ( $data eq 'Y' ) {
+        print "Deleting Repos ...\n";
+        $self->run_github("repos->delete( { confirm => 1 } )");
+    }
+}
+
+# Issues
+sub issue_open {
+    my ($self) = @_;
+
+    my %data;
+    foreach my $col ( 'title', 'body' ) {
+        my $data = $self->term->readline( ucfirst($col) . ': ' );
+        $data{$col} = $data;
+    }
+
+    $self->run_github(qq~issue->open( "$data{title}", "$data{body}" )~);
+}
+
 1;
 __END__
 
@@ -225,7 +327,7 @@ App::GitHub - GitHub Command Tools
 
 =head1 VERSION
 
-version 0.01
+version 0.02
 
 =head1 SYNOPSIS
 
